@@ -30,6 +30,7 @@ __all__ = [
     'diffusionmap',
     'dihedrals',
     'distances',
+    'dielectric',
     'gnm',
     'hbonds',
     'helix_analysis',
@@ -39,6 +40,7 @@ __all__ = [
     'lineardensity',
     'msd',
     'nuclinfo',
+    'nucleicacids',
     'polymer',
     'pca',
     'psa',
