@@ -20,11 +20,105 @@
 # MDAnalysis: A Toolkit for the Analysis of Molecular Dynamics Simulations.
 # J. Comput. Chem. 32 (2011), 2319--2327, doi:10.1002/jcc.21787
 #
-"""
-Analysis building blocks --- :mod:`MDAnalysis.analysis.base`
+"""Analysis building blocks --- :mod:`MDAnalysis.analysis.base`
 ============================================================
 
-The building blocks for creating Analysis classes.
+MDAnalysis provides building blocks for creating analysis classes. One can
+think of each analysis class as a "tool" that performs a specific analysis over
+the trajectory frames and stores the results in the tool.
+
+Analysis classes are derived from :class:`AnalysisBase` by subclassing. This
+inheritance provides a common workflow and API for users and makes many
+additional features automatically available (such as frame selections and a
+verbose progressbar). The important points for analysis classes are:
+
+#. Analysis tools are Python classes derived from :class:`AnalysisBase`.
+#. When instantiating an analysis, the :class:`Universe` or :class:`AtomGroup`
+   that the analysis operates on is provided together with any other parameters
+   that are kept fixed for the specific analysis.
+#. The analysis is performed with :meth:`~AnalysisBase.run` method. It has a
+   common set of arguments such as being able to select the frames the analysis
+   is performed on. The `verbose` keyword argument enables additional output. A
+   progressbar is shown by default that also shows an estimate for the
+   remaining time until the end of the analysis.
+#. Results are always stored in the attribute :attr:`AnalysisBase.results`,
+   which is an instance of :class:`Results`, a kind of dictionary that allows
+   allows item access via attributes. Each analysis class decides what and how
+   to store in :class:`Results` and needs to document it. For time series, the
+   :attr:`AnalysisBase.times` contains the time stamps of the analyzed frames.
+
+
+Example of using a standard analysis tool
+-----------------------------------------
+
+For example, the :class:`MDAnalysis.analysis.rms.RMSD` performs a
+root-mean-square distance analysis in the following way:
+
+.. code-block:: python
+
+   import MDAnalysis as mda
+   from MDAnalysisTests.datafiles import TPR, XTC
+
+   from MDAnalysis.analysis import rms
+
+   u = mda.Universe(TPR, XTC)
+
+   # (2) instantiate analysis
+   rmsd = rms.RMSD(u, select='name CA')
+
+   # (3) the run() method can select frames in different ways
+   # run on all frames (with progressbar)
+   rmsd.run(verbose=True)
+
+   # or start, stop, and step can be used
+   rmsd.run(start=2, stop=8, step=2)
+
+   # a list of frames to run the analysis on can be passed
+   rmsd.run(frames=[0,2,3,6,9])
+
+   # a list of booleans the same length of the trajectory can be used
+   rmsd.run(frames=[True, False, True, True, False, False, True, False,
+                    False, True])
+
+   # (4) analyze the results, e.g., plot
+   t = rmsd.times
+   y = rmsd.results.rmsd[:, 2]   # RMSD at column index 2, see docs
+
+   import matplotlib.pyplot as plt
+   plt.plot(t, y)
+   plt.xlabel("time (ps)")
+   plt.ylabel("RMSD (Å)")
+
+
+Writing new analysis tools
+--------------------------
+
+In order to write new analysis tools, derive a class from :class:`AnalysisBase`
+and define at least the :meth:`_single_frame` method, as described in
+:class:`AnalysisBase`.
+
+.. SeeAlso::
+
+   The chapter `Writing your own trajectory analysis`_ in the *User Guide*
+   contains a step-by-step example for writing analysis tools with
+   :class:`AnalysisBase`.
+
+
+.. _`Writing your own trajectory analysis`:
+   https://userguide.mdanalysis.org/stable/examples/analysis/custom_trajectory_analysis.html
+
+
+Classes
+-------
+
+The :class:`Results` and :class:`AnalysisBase` classes are the essential
+building blocks for almost all MDAnalysis tools in the
+:mod:`MDAnalysis.analysis` module. They aim to be easily useable and
+extendable.
+
+:class:`AnalysisFromFunction` and the :func:`analysis_class` functions are
+simple wrappers that make it even easier to create fully-featured analysis
+tools if only the single-frame analysis function needs to be written.
 
 """
 from collections import UserDict
@@ -43,10 +137,10 @@ logger = logging.getLogger(__name__)
 class Results(UserDict):
     r"""Container object for storing results.
 
-    ``Results`` are dictionaries that provide two ways by which values can be
-    accessed: by dictionary key ``results["value_key"]`` or by object
-    attribute, ``results.value_key``. ``Results`` stores all results obtained
-    from an analysis after calling :func:`run()`.
+    :class:`Results` are dictionaries that provide two ways by which values
+    can be accessed: by dictionary key ``results["value_key"]`` or by object
+    attribute, ``results.value_key``. :class:`Results` stores all results
+    obtained from an analysis after calling :meth:`~AnalysisBase.run()`.
 
     The implementation is similar to the :class:`sklearn.utils.Bunch`
     class in `scikit-learn`_.
@@ -134,7 +228,7 @@ class AnalysisBase(object):
     reader for iterating, and it offers to show a progress meter.
     Computed results are stored inside the :attr:`results` attribute.
 
-    To define a new Analysis, `AnalysisBase` needs to be subclassed
+    To define a new Analysis, :class:`AnalysisBase` needs to be subclassed
     and :meth:`_single_frame` must be defined. It is also possible to define
     :meth:`_prepare` and :meth:`_conclude` for pre- and post-processing.
     All results should be stored as attributes of the :class:`Results`
@@ -210,12 +304,12 @@ class AnalysisBase(object):
 
 
     .. versionchanged:: 1.0.0
-        Support for setting ``start``, ``stop``, and ``step`` has been
-        removed. These should now be directly passed to
-        :meth:`AnalysisBase.run`.
+        Support for setting `start`, `stop`, and `step` has been removed. These
+        should now be directly passed to :meth:`AnalysisBase.run`.
 
     .. versionchanged:: 2.0.0
         Added :attr:`results`
+
     """
 
     def __init__(self, trajectory, verbose=False, **kwargs):
@@ -223,9 +317,9 @@ class AnalysisBase(object):
         self._verbose = verbose
         self.results = Results()
 
-    def _setup_frames(self, trajectory, start=None, stop=None, step=None):
-        """
-        Pass a Reader object and define the desired iteration pattern
+    def _setup_frames(self, trajectory, start=None, stop=None, step=None,
+                      frames=None):
+        """Pass a Reader object and define the desired iteration pattern
         through the trajectory
 
         Parameters
@@ -238,17 +332,42 @@ class AnalysisBase(object):
             stop frame of analysis
         step : int, optional
             number of frames to skip between each analysed frame
+        frames : array_like, optional
+            array of integers or booleans to slice trajectory; cannot be
+            combined with `start`, `stop`, `step`
+
+            .. versionadded:: 2.2.0
+
+        Raises
+        ------
+        ValueError
+            if *both* `frames` and at least one of `start`, `stop`, or `frames`
+            is provided (i.e., set to another value than ``None``)
 
 
         .. versionchanged:: 1.0.0
             Added .frames and .times arrays as attributes
+
+        .. versionchanged:: 2.2.0
+            Added ability to iterate through trajectory by passing a list of
+            frame indices in the `frames` keyword argument
+
         """
         self._trajectory = trajectory
-        start, stop, step = trajectory.check_slice_indices(start, stop, step)
+        if frames is not None:
+            if not all(opt is None for opt in [start, stop, step]):
+                raise ValueError("start/stop/step cannot be combined with "
+                                 "frames")
+            slicer = frames
+        else:
+            start, stop, step = trajectory.check_slice_indices(start, stop,
+                                                               step)
+            slicer = slice(start, stop, step)
+        self._sliced_trajectory = trajectory[slicer]
         self.start = start
         self.stop = stop
         self.step = step
-        self.n_frames = len(range(start, stop, step))
+        self.n_frames = len(self._sliced_trajectory)
         self.frames = np.zeros(self.n_frames, dtype=int)
         self.times = np.zeros(self.n_frames)
 
@@ -264,13 +383,14 @@ class AnalysisBase(object):
         pass  # pylint: disable=unnecessary-pass
 
     def _conclude(self):
-        """Finalise the results you've gathered.
+        """Finalize the results you've gathered.
 
         Called at the end of the :meth:`run` method to finish everything up.
         """
         pass  # pylint: disable=unnecessary-pass
 
-    def run(self, start=None, stop=None, step=None, verbose=None):
+    def run(self, start=None, stop=None, step=None, frames=None,
+            verbose=None):
         """Perform the calculation
 
         Parameters
@@ -281,25 +401,41 @@ class AnalysisBase(object):
             stop frame of analysis
         step : int, optional
             number of frames to skip between each analysed frame
+        frames : array_like, optional
+            array of integers or booleans to slice trajectory; `frames` can
+            only be used *instead* of `start`, `stop`, and `step`. Setting
+            *both* `frames` and at least one of `start`, `stop`, `step` to a
+            non-default value will raise a :exc:`ValueError`.
+
+            .. versionadded:: 2.2.0
+
         verbose : bool, optional
             Turn on verbosity
+
+
+        .. versionchanged:: 2.2.0
+            Added ability to analyze arbitrary frames by passing a list of
+            frame indices in the `frames` keyword argument.
+
         """
         logger.info("Choosing frames to analyze")
         # if verbose unchanged, use class default
         verbose = getattr(self, '_verbose',
                           False) if verbose is None else verbose
 
-        self._setup_frames(self._trajectory, start, stop, step)
+        self._setup_frames(self._trajectory, start=start, stop=stop,
+                           step=step, frames=frames)
         logger.info("Starting preparation")
         self._prepare()
+        logger.info("Starting analysis loop over %d trajectory frames",
+                    self.n_frames)
         for i, ts in enumerate(ProgressBar(
-                self._trajectory[self.start:self.stop:self.step],
+                self._sliced_trajectory,
                 verbose=verbose)):
             self._frame_index = i
             self._ts = ts
             self.frames[i] = ts.frame
             self.times[i] = ts.time
-            # logger.info("--> Doing frame {} of {}".format(i+1, self.n_frames))
             self._single_frame()
         logger.info("Finishing up")
         self._conclude()
@@ -313,13 +449,13 @@ class AnalysisFromFunction(AnalysisBase):
     ----------
     function : callable
         function to evaluate at each frame
-    trajectory : mda.coordinates.Reader, optional
+    trajectory : MDAnalysis.coordinates.Reader, optional
         trajectory to iterate over. If ``None`` the first AtomGroup found in
         args and kwargs is used as a source for the trajectory.
     *args : list
-        arguments for ``function``
+        arguments for `function`
     **kwargs : dict
-        arguments for ``function`` and :class:`AnalysisBase`
+        arguments for `function` and :class:`AnalysisBase`
 
     Attributes
     ----------
@@ -334,7 +470,7 @@ class AnalysisFromFunction(AnalysisBase):
     Raises
     ------
     ValueError
-        if ``function`` has the same ``kwargs`` as :class:`AnalysisBase`
+        if `function` has the same `kwargs` as :class:`AnalysisBase`
 
     Example
     -------
@@ -349,9 +485,9 @@ class AnalysisFromFunction(AnalysisBase):
 
 
     .. versionchanged:: 1.0.0
-        Support for directly passing the ``start``, ``stop``, and ``step``
-        arguments has been removed. These should instead be passed
-        to :meth:`AnalysisFromFunction.run`.
+        Support for directly passing the `start`, `stop`, and `step` arguments
+        has been removed. These should instead be passed to
+        :meth:`AnalysisFromFunction.run`.
 
     .. versionchanged:: 2.0.0
         Former :attr:`results` are now stored as :attr:`results.timeseries`
@@ -415,7 +551,7 @@ def analysis_class(function):
     Raises
     ------
     ValueError
-        if ``function`` has the same ``kwargs`` as :class:`AnalysisBase`
+        if `function` has the same `kwargs` as :class:`AnalysisBase`
 
     Examples
     --------
@@ -441,7 +577,7 @@ def analysis_class(function):
 
 
     .. versionchanged:: 2.0.0
-        Former ``results`` are now stored as ``results.timeseries``
+        Former :attr:`results` are now stored as :attr:`results.timeseries`
     """
 
     class WrapperClass(AnalysisFromFunction):
@@ -454,7 +590,8 @@ def analysis_class(function):
 
 def _filter_baseanalysis_kwargs(function, kwargs):
     """
-    create two dictionaries with kwargs separated for function and AnalysisBase
+    Create two dictionaries with `kwargs` separated for `function` and
+    :class:`AnalysisBase`
 
     Parameters
     ----------
@@ -473,7 +610,8 @@ def _filter_baseanalysis_kwargs(function, kwargs):
     Raises
     ------
     ValueError
-        if ``function`` has the same ``kwargs`` as :class:`AnalysisBase`
+        if `function` has the same `kwargs` as :class:`AnalysisBase`
+
     """
     try:
         # pylint: disable=deprecated-method
