@@ -102,13 +102,6 @@ atomgroup.
    :members:
    :inherited-members: run
 
-   .. attribute:: results.density
-
-      After the analysis (see the :meth:`~DensityAnalysis.run` method), the
-      resulting density is stored in the :attr:`results.density` attribute as
-      a :class:`Density` instance. Note: this replaces the now deprecated
-      :attr:`density` attribute.
-
    .. automethod:: _set_user_grid
 
 
@@ -217,6 +210,11 @@ class DensityAnalysis(AnalysisBase):
             A :class:`Density` instance containing a physical density of units
             :math:`Angstrom^{-3}`.
 
+            After the analysis (see the :meth:`~DensityAnalysis.run` method),
+            the resulting density is stored in the :attr:`results.density`
+            attribute as a :class:`Density` instance. Note: this replaces the
+            now deprecated :attr:`density` attribute.
+
     density : :class:`Density`
             Alias to the :attr:`results.density`.
 
@@ -235,7 +233,8 @@ class DensityAnalysis(AnalysisBase):
 
     See Also
     --------
-    pmda.density.DensityAnalysis for a parallel version
+    pmda.density.DensityAnalysis
+        A parallel version of :class:`DensityAnalysis`
 
     Notes
     -----
@@ -396,6 +395,7 @@ class DensityAnalysis(AnalysisBase):
        :func:`_set_user_grid` is now a method of :class:`DensityAnalysis`.
        :class:`Density` results are now stored in a
        :class:`MDAnalysis.analysis.base.Results` instance.
+
     """
 
     def __init__(self, atomgroup, delta=1.0,
@@ -463,7 +463,7 @@ class DensityAnalysis(AnalysisBase):
         bins = BINS['Nbins']
         # create empty grid with the right dimensions (and get the edges)
         grid, edges = np.histogramdd(np.zeros((1, 3)), bins=bins,
-                                     range=arange, normed=False)
+                                     range=arange, density=False)
         grid *= 0.0
         self._grid = grid
         self._edges = edges
@@ -473,7 +473,7 @@ class DensityAnalysis(AnalysisBase):
     def _single_frame(self):
         h, _ = np.histogramdd(self._atomgroup.positions,
                               bins=self._bins, range=self._arange,
-                              normed=False)
+                              density=False)
         # reduce (proposed change #2542 to match the parallel version in pmda.density)
         # return self._reduce(self._grid, h)
         #
@@ -644,7 +644,7 @@ class Density(Grid):
 
     If the input histogram consists of counts per cell then the
     :meth:`Density.make_density` method converts the grid to a physical density. For
-    a probability density, divide it by :meth:`Density.grid.sum` or use ``normed=True``
+    a probability density, divide it by :meth:`Density.grid.sum` or use ``density=True``
     right away in :func:`~numpy.histogramdd`.
 
     The user *should* set the *parameters* keyword (see docs for the
@@ -866,7 +866,7 @@ class Density(Grid):
 
         """
         if not self.parameters['isDensity']:
-            errmsg = 'The grid is not a density so converty_density() makes no sense.'
+            errmsg = 'The grid is not a density so convert_density() makes no sense.'
             logger.fatal(errmsg)
             raise RuntimeError(errmsg)
         if unit == self.units['density']:
