@@ -307,7 +307,12 @@ class HELANAL(AnalysisBase):
     flatten_single_helix : bool, optional
         Whether to flatten results if only one selection is passed.
     split_residue_sequences : bool, optional
-        Wether to split residues into a list of same or consecutive helices.
+        Whether to split the residue sequence into individual helices.
+        This keyword only applies if a residue gap is present in the
+        AtomGroup generated by a ``select`` string.
+        If ``False``, the residues will be analysed as a single helix.
+        If ``True``, each group of consecutive residues will be treated
+        as a separate helix.
     verbose : bool, optional
         Turn on more logging and debugging.
 
