@@ -20,140 +20,6 @@
 # MDAnalysis: A Toolkit for the Analysis of Molecular Dynamics Simulations.
 # J. Comput. Chem. 32 (2011), 2319--2327, doi:10.1002/jcc.21787
 #
-
-"""HOLE Analysis --- :mod:`MDAnalysis.analysis.hole2.hole`
-=====================================================================================
-
-:Author: Lily Wang
-:Year: 2020
-:Copyright: GNU Public License v3
-
-.. versionadded:: 1.0.0
-
-This module contains the tools to interface with HOLE_ [Smart1993]_
-[Smart1996]_ to analyse an ion channel pore or transporter pathway [Stelzl2014]_ .
-
-Using HOLE on a PDB file
-------------------------
-
-Use the :func:``hole`` function to run `HOLE`_ on a single PDB file. For example,
-the code below runs the `HOLE`_ program installed at '~/hole2/exe/hole' ::
-
-    from MDAnalysis.tests.datafiles import PDB_HOLE
-    from MDAnalysis.analysis import hole2
-    profiles = hole2.hole(PDB_HOLE, executable='~/hole2/exe/hole')
-    # to create a VMD surface of the pore
-    hole2.create_vmd_surface(filename='hole.vmd')
-
-``profiles`` is a dictionary of HOLE profiles, indexed by the frame number. If only
-a PDB file is passed to the function, there will only be one profile at frame 0.
-You can visualise the pore by loading your PDB file into VMD, and in
-Extensions > Tk Console, type::
-
-    source hole.vmd
-
-You can also pass a DCD trajectory with the same atoms in the same order as
-your PDB file with the ``dcd`` keyword argument. In that case, ``profiles`` will
-contain multiple HOLE profiles, indexed by frame.
-
-The HOLE program will create some output files:
-
-    * an output file (default name: hole.out)
-    * an sphpdb file (default name: hole.sph)
-    * a file of van der Waals' radii
-      (if not specified with ``vdwradii_file``. Default name: simple2.rad)
-    * a symlink of your PDB or DCD files (if the original name is too long)
-    * the input text (if you specify ``infile``)
-
-By default (`keep_files=True`), these files are kept. If you would like to
-delete the files after the function is wrong, set `keep_files=False`. Keep in
-mind that if you delete the sphpdb file, you cannot then create a VMD surface.
-
-
-Using HOLE on a trajectory
---------------------------
-
-You can also run HOLE on a trajectory through the :class:`HoleAnalysis` class.
-This behaves similarly to the ``hole`` function, although arguments such as ``cpoint``
-and ``cvect`` become runtime arguments for the :meth:`~HoleAnalysis.run` function.
-
-The class can be set-up and run like a normal MDAnalysis analysis class::
-
-    import MDAnalysis as mda
-    from MDAnalysis.tests.datafiles import MULTIPDB_HOLE
-    from MDAnalysis.analysis import hole2
-
-    ha = hole2.HoleAnalysis(u, executable='~/hole2/exe/hole') as h2:
-    ha.run()
-    ha.create_vmd_surface(filename='hole.vmd')
-
-The VMD surface created by the class updates the pore for each frame of the trajectory.
-Use it as normal by loading your trajectory in VMD and sourcing the file in the Tk Console.
-
-You can access the actual profiles generated in the ``results`` attribute::
-
-    print(ha.results.profiles)
-
-Again, HOLE writes out files for each frame. If you would like to delete these files
-after the analysis, you can call :meth:`~HoleAnalysis.delete_temporary_files`::
-
-    ha.delete_temporary_files()
-
-Alternatively, you can use HoleAnalysis as a context manager that deletes temporary
-files when you are finished with the context manager::
-
-    import MDAnalysis as mda
-    from MDAnalysis.tests.datafiles import MULTIPDB_HOLE
-    from MDAnalysis.analysis import hole2
-
-    with hole2.HoleAnalysis(u, executable='~/hole2/exe/hole') as h2:
-        h2.run()
-        h2.create_vmd_surface()
-
-
-.. _HOLE: http://www.holeprogram.org
-
-
-Functions and classes
----------------------
-
-.. autofunction:: hole
-
-.. autoclass:: HoleAnalysis
-   :members:
-
-
-References
-----------
-
-.. [Smart1993] O.S. Smart, J.M. Goodfellow and B.A. Wallace.
-               The Pore Dimensions of Gramicidin A. Biophysical Journal 65:2455-2460, 1993.
-               DOI: 10.1016/S0006-3495(93)81293-1
-.. [Smart1996] O.S. Smart, J.G. Neduvelil, X. Wang, B.A. Wallace, and M.S.P. Sansom.
-               HOLE: A program for the analysis of the pore dimensions of ion channel
-               structural models. J.Mol.Graph., 14:354–360, 1996.
-               DOI: 10.1016/S0263-7855(97)00009-X
-               URL http://www.holeprogram.org/
-.. [Stelzl2014] L. S. Stelzl, P. W. Fowler, M. S. P. Sansom, and O. Beckstein.
-               Flexible gates generate occluded intermediates in the transport cycle
-               of LacY. J Mol Biol, 426:735–751, 2014.
-               DOI: 10.1016/j.jmb.2013.10.024
-
-.. Footnotes
-
-.. [#HOLEDCD] PDB files are not the only files that :program:`hole` can
-              read. In principle, it is also able to read CHARMM DCD
-              trajectories and generate a hole profile for each frame. However,
-              native support for DCD in :program:`hole` is patchy and not every
-              DCD is recognized. In particular, At the moment, DCDs generated
-              with MDAnalysis are not accepted by HOLE. To overcome this
-              PDB / DCD limitation, use :class:`HoleAnalysis` which creates
-              temporary PDB files for each frame of a
-              :class:`~MDAnalysis.core.universe.Universe` or
-              :class:`~MDAnalysis.core.universe.AtomGroup` and runs
-              :func:``hole`` on each of them.
-
-"""
 import os
 import errno
 import tempfile
@@ -174,7 +40,7 @@ from .utils import (check_and_fix_long_filename, write_simplerad2,
                     set_up_hole_input, run_hole, collect_hole,
                     create_vmd_surface)
 from .templates import (hole_input, hole_lines, vmd_script_array,
-                        vmd_script_function,
+                        vmd_script_function, exe_err,
                         IGNORE_RESIDUES)
 
 logger = logging.getLogger(__name__)
@@ -560,7 +426,7 @@ class HoleAnalysis(AnalysisBase):
 
     .. versionchanged:: 2.0.0
         :attr:`sphpdbs`, :attr:`outfiles` and :attr:`profiles `
-        are now stored in a :class:`MDAnalysis.analysis.base.Results` 
+        are now stored in a :class:`MDAnalysis.analysis.base.Results`
         instance.
 
     """
@@ -642,7 +508,7 @@ class HoleAnalysis(AnalysisBase):
         # --- finding executables ----
         hole = util.which(executable)
         if hole is None:
-            raise OSError(errno.ENOENT, exe_err.format(name=hole,
+            raise OSError(errno.ENOENT, exe_err.format(name=executable,
                                                        kw='executable'))
         self.base_path = os.path.dirname(hole)
 
@@ -655,7 +521,7 @@ class HoleAnalysis(AnalysisBase):
                                                        kw='sos_triangle'))
         sph_process_path = util.which(sph_process)
         if sph_process_path is None:
-            path = os.path.join(self.base_path, 'sph_process')
+            path = os.path.join(self.base_path, sph_process)
             sph_process_path = util.which(path)
         if sph_process_path is None:
             raise OSError(errno.ENOENT, exe_err.format(name=sph_process,
@@ -684,6 +550,7 @@ class HoleAnalysis(AnalysisBase):
             filenames.extend(universe.trajectory.filenames)
         except AttributeError:
             filenames.append(universe.trajectory.filename)
+        filenames = [name for name in filenames if name is not None]
         hole_filenames = '\n!    '.join(filenames)
         self._input_header = self.hole_header.format(hole_filenames)
 
@@ -785,8 +652,8 @@ class HoleAnalysis(AnalysisBase):
         i = self._frame_index
         outfile = self.output_file.format(prefix=self.prefix, i=frame)
         sphpdb = self.sphpdb_file.format(prefix=self.prefix, i=frame)
-        self.sphpdbs[i] = sphpdb
-        self.outfiles[i] = outfile
+        self.results.sphpdbs[i] = sphpdb
+        self.results.outfiles[i] = outfile
         if outfile not in self.tmp_files:
             self.tmp_files.append(outfile)
         if sphpdb not in self.tmp_files:
@@ -832,11 +699,15 @@ class HoleAnalysis(AnalysisBase):
                            double_water_color='blue'):
         """Process HOLE output to create a smooth pore surface suitable for VMD.
 
-        Takes the ``sphpdb`` file for each frame and feeds it to `sph_process <http://www.holeprogram.org/doc/old/hole_d04.html#sph_process>`_
-        and `sos_triangle <http://www.holeprogram.org/doc/old/hole_d04.html#sos_triangle>`_ as described under `Visualization of HOLE
-        results <http://www.holeprogram.org/doc/index.html>`_.
+        Takes the ``sphpdb`` file for each frame and feeds it to `sph_process
+        <http://www.holeprogram.org/doc/old/hole_d04.html#sph_process>`_ and
+        `sos_triangle
+        <http://www.holeprogram.org/doc/old/hole_d04.html#sos_triangle>`_ as
+        described under `Visualization of HOLE results
+        <http://www.holeprogram.org/doc/index.html>`_.
 
-        Load the output file *filename* into VMD in Extensions > Tk Console ::
+        Load the output file *filename* into VMD in :menuselection:`Extensions
+        --> Tk Console` ::
 
            source hole.vmd
 
@@ -884,7 +755,7 @@ class HoleAnalysis(AnalysisBase):
             raise ValueError('No sphpdb files to read. Try calling run()')
 
         frames = []
-        for i in self.frames:
+        for i, frame in enumerate(self.frames):
             sphpdb = self.results.sphpdbs[i]
             tmp_tri = create_vmd_surface(sphpdb=sphpdb,
                                          sph_process=self.exe['sph_process'],
@@ -915,7 +786,7 @@ class HoleAnalysis(AnalysisBase):
                 pass
 
             tri = '{ { ' + ' } { '.join(list(map(' '.join, shapes))) + ' } }'
-            frames.append('set triangles({i}) '.format(i=i) + tri)
+            frames.append(f'set triangles({i}) ' + tri)
 
         trinorms = '\n'.join(frames)
         vmd_1 = vmd_script_array.format(no_water_color=no_water_color,
@@ -1300,14 +1171,14 @@ class HoleAnalysis(AnalysisBase):
             Profiles to include by frame. If ``None``, includes
             all frames.
         bins : int or iterable of edges, optional
-            If bins is an int, it defines the number of equal-width bins in the given 
-            range. If bins is a sequence, it defines a monotonically increasing array of 
+            If bins is an int, it defines the number of equal-width bins in the given
+            range. If bins is a sequence, it defines a monotonically increasing array of
             bin edges, including the rightmost edge, allowing for non-uniform bin widths.
         range : (float, float), optional
             The lower and upper range of the bins.
             If not provided, ``range`` is simply ``(a.min(), a.max())``,
             where ``a`` is the array of reaction coordinates.
-            Values outside the range are ignored. The first element of the range must be 
+            Values outside the range are ignored. The first element of the range must be
             less than or equal to the second.
 
 
@@ -1358,14 +1229,14 @@ class HoleAnalysis(AnalysisBase):
             Profiles to include by frame. If ``None``, includes
             all frames.
         bins : int or iterable of edges, optional
-            If bins is an int, it defines the number of equal-width bins in the given 
-            range. If bins is a sequence, it defines a monotonically increasing array of 
+            If bins is an int, it defines the number of equal-width bins in the given
+            range. If bins is a sequence, it defines a monotonically increasing array of
             bin edges, including the rightmost edge, allowing for non-uniform bin widths.
         range : (float, float), optional
             The lower and upper range of the bins.
             If not provided, ``range`` is simply ``(a.min(), a.max())``,
             where ``a`` is the array of reaction coordinates.
-            Values outside the range are ignored. The first element of the range must be 
+            Values outside the range are ignored. The first element of the range must be
             less than or equal to the second.
 
 
@@ -1394,14 +1265,14 @@ class HoleAnalysis(AnalysisBase):
             Profiles to include by frame. If ``None``, includes
             all frames.
         bins : int or iterable of edges, optional
-            If bins is an int, it defines the number of equal-width bins in the given 
-            range. If bins is a sequence, it defines a monotonically increasing array of 
+            If bins is an int, it defines the number of equal-width bins in the given
+            range. If bins is a sequence, it defines a monotonically increasing array of
             bin edges, including the rightmost edge, allowing for non-uniform bin widths.
         range : (float, float), optional
             The lower and upper range of the bins.
             If not provided, ``range`` is simply ``(a.min(), a.max())``,
             where ``a`` is the array of reaction coordinates.
-            Values outside the range are ignored. The first element of the range must be 
+            Values outside the range are ignored. The first element of the range must be
             less than or equal to the second.
         color : str or array-like, optional
             Color for the plot.
@@ -1432,7 +1303,7 @@ class HoleAnalysis(AnalysisBase):
 
         binned, bins = self.bin_radii(frames=frames, bins=bins, range=range)
         mean = np.array(list(map(np.mean, binned)))
-        midpoints = 0.5 * bins[1:] + bins[:-1]
+        midpoints = 0.5 * (bins[1:] + bins[:-1])
 
         fig, ax = plt.subplots()
         if n_std:
