@@ -38,21 +38,18 @@ Generation and Analysis of X3DNA helicoidal parameter profiles --- :mod:`MDAnaly
 .. _`issue 906`: https://github.com/MDAnalysis/mdanalysis/issues/906
 
 With the help of this module, X3DNA_ can be run on frames in a trajectory. Data
-can be combined and analyzed. X3DNA_ [Lu2003]_ [Lu2008]_ must be installed
+can be combined and analyzed. X3DNA_ :cite:p:`Lu2003,Lu2008` must be installed
 separately.
 
 
 .. rubric:: References
 
-.. [Lu2003] Xiang-Jun Lu & Wilma K. Olson (2003).
-            3DNA: a software package for the analysis, rebuilding and visualization
-            for three-dimensional nucleic acid structure
-            Nucleic Acids Res. 31(17), 5108-21.
+.. bibliography::
+    :filter: False
+    :style: MDA
 
-.. [Lu2008] Xiang-Jun Lu & Wilma K. Olson (2008).
-            3DNA: a versatile, integrated software system for the analysis, rebuilding
-            and visualization of three-dimensional nucleic-acid structures.
-            Nat Protoc. 3(7), 1213-27.
+    Lu2003
+    Lu2008
 
 .. _X3DNA: http://x3dna.org/
 
