@@ -151,7 +151,9 @@ import collections
 import numpy as np
 
 from ..lib import util
+from ..lib.util import store_init_arguments
 from . import base
+from .timestep import Timestep
 from ..topology.core import guess_atom_element
 from ..exceptions import NoDataError
 
@@ -244,6 +246,7 @@ class PDBReader(base.ReaderBase):
     format = ['PDB', 'ENT']
     units = {'time': None, 'length': 'Angstrom'}
 
+    @store_init_arguments
     def __init__(self, filename, **kwargs):
         """Read coordinates from *filename*.
 
@@ -537,24 +540,27 @@ class PDBWriter(base.WriterBase):
        An indexing issue meant it previously used the first charater (Issue #2224)
 
     .. versionchanged:: 2.0.0
-        Add the `redindex` argument. Setting this keyword to ``True``
-        (the default) preserves the behavior in earlier versions of MDAnalysis.
-        The PDB writer checks for a valid chainID entry instead of using the
-        last character of segid. Should a chainID not be present, or not
-        conform to the PDB standard, the default value of  'X' is used.
+       Add the `redindex` argument. Setting this keyword to ``True``
+       (the default) preserves the behavior in earlier versions of MDAnalysis.
+       The PDB writer checks for a valid chainID entry instead of using the
+       last character of segid. Should a chainID not be present, or not
+       conform to the PDB standard, the default value of  'X' is used.
 
+    .. versionchanged:: 2.3.0
+       Do not write unusable conect records when ag index
+       is larger than 100000.
     """
     fmt = {
         'ATOM': (
             "ATOM  {serial:5d} {name:<4s}{altLoc:<1s}{resName:<4s}"
             "{chainID:1s}{resSeq:4d}{iCode:1s}"
             "   {pos[0]:8.3f}{pos[1]:8.3f}{pos[2]:8.3f}{occupancy:6.2f}"
-            "{tempFactor:6.2f}      {segID:<4s}{element:>2s}\n"),
+            "{tempFactor:6.2f}      {segID:<4s}{element:>2s}{charge:2s}\n"),
         'HETATM': (
             "HETATM{serial:5d} {name:<4s}{altLoc:<1s}{resName:<4s}"
             "{chainID:1s}{resSeq:4d}{iCode:1s}"
             "   {pos[0]:8.3f}{pos[1]:8.3f}{pos[2]:8.3f}{occupancy:6.2f}"
-            "{tempFactor:6.2f}      {segID:<4s}{element:>2s}\n"),
+            "{tempFactor:6.2f}      {segID:<4s}{element:>2s}{charge:2s}\n"),
         'REMARK': "REMARK     {0}\n",
         'COMPND': "COMPND    {0}\n",
         'HEADER': "HEADER    {0}\n",
@@ -848,6 +854,10 @@ class PDBWriter(base.WriterBase):
         for a1, a2 in bonds:
             if not (a1 in mapping and a2 in mapping):
                 continue
+            if mapping[a1] >= 100000 or mapping[a2] >= 100000:
+                warnings.warn("Atom with index >=100000 cannot write "
+                              "bonds to PDB CONECT records.")
+                return
             con[a2].append(a1)
             con[a1].append(a2)
 
@@ -868,13 +878,13 @@ class PDBWriter(base.WriterBase):
         * :attr:`PDBWriter.trajectory` (the underlying trajectory
           :class:`~MDAnalysis.coordinates.base.Reader`)
         * :attr:`PDBWriter.timestep` (the underlying trajectory
-          :class:`~MDAnalysis.coordinates.base.Timestep`)
+          :class:`~MDAnalysis.coordinates.timestep.Timestep`)
 
         Before calling :meth:`_write_next_frame` this method **must** be
         called at least once to enable extracting topology information from the
         current frame.
         """
-        if isinstance(obj, base.Timestep):
+        if isinstance(obj, Timestep):
             raise TypeError("PDBWriter cannot write Timestep objects "
                             "directly, since they lack topology information ("
                             "atom names and types) required in PDB files")
@@ -968,14 +978,14 @@ class PDBWriter(base.WriterBase):
 
         :Keywords:
           *ts*
-             :class:`base.Timestep` object containing coordinates to be written to trajectory file;
+             :class:`timestep.Timestep` object containing coordinates to be written to trajectory file;
              if ``None`` then :attr:`PDBWriter.ts`` is tried.
           *multiframe*
              ``False``: write a single frame (default); ``True`` behave as a trajectory writer
 
         .. Note::
 
-           Before using this method with another :class:`base.Timestep` in the *ts*
+           Before using this method with another :class:`timestep.Timestep` in the *ts*
            argument, :meth:`PDBWriter._update_frame` *must* be called
            with the :class:`~MDAnalysis.core.groups.AtomGroup.Universe` as
            its argument so that topology information can be gathered.
@@ -1020,6 +1030,47 @@ class PDBWriter(base.WriterBase):
             return '{:<4}'.format(atomname)
         return ' {:<3}'.format(atomname)
 
+    @staticmethod
+    def _format_PDB_charges(charges: np.ndarray) -> np.ndarray:
+        """Format formal charges to match PDB requirements.
+
+        Formal charge entry is set to empty if charge is 0, otherwise the
+        charge is set to a two character ```<charge value><charge sign>``
+        entry, e.g. ``1+`` or ``2-``.
+
+        This method also verifies that formal charges can adhere to the PDB
+        format (i.e. charge cannot be > 9 or < -9).
+
+        Parameters
+        ----------
+        charges: np.ndarray
+            NumPy array of integers representing the formal charges of
+            the atoms being written.
+
+        Returns
+        -------
+        np.ndarray
+            NumPy array of dtype object with strings representing the
+            formal charges of the atoms being written.
+        """
+        if not np.issubdtype(charges.dtype, np.integer):
+            raise ValueError("formal charges array should be of `int` type")
+
+        outcharges = charges.astype(object)
+        outcharges[outcharges == 0] = ''  # empty strings for no charge case
+        # using np.where is more efficient than looping in sparse cases
+        for i in np.where(charges < 0)[0]:
+            if charges[i] < -9:
+                errmsg = "formal charge < -9 is not supported by PDB standard"
+                raise ValueError(errmsg)
+            outcharges[i] = f"{abs(charges[i])}-"
+        for i in np.where(charges > 0)[0]:
+            if charges[i] > 9:
+                errmsg = "formal charge > 9 is not supported by PDB standard"
+                raise ValueError(errmsg)
+            outcharges[i] = f"{charges[i]}+"
+        return outcharges
+
     def _write_timestep(self, ts, multiframe=False):
         """Write a new timestep *ts* to file
 
@@ -1090,6 +1141,7 @@ class PDBWriter(base.WriterBase):
         atomnames = get_attr('names', 'X')
         elements = get_attr('elements', ' ')
         record_types = get_attr('record_types', 'ATOM')
+        formal_charges = self._format_PDB_charges(get_attr('formalcharges', 0))
 
         def validate_chainids(chainids, default):
             """Validate each atom's chainID
@@ -1155,6 +1207,7 @@ class PDBWriter(base.WriterBase):
             vals['segID'] = segids[i][:4]
             vals['chainID'] = chainids[i]
             vals['element'] = elements[i][:2].upper()
+            vals['charge'] = formal_charges[i]
 
             # record_type attribute, if exists, can be ATOM or HETATM
             try:
