@@ -41,28 +41,6 @@ AMBER trajectories are assumed to be in the following units:
 * lengths in Angstrom (Å)
 * time in ps (but see below)
 
-AMBER trajectory coordinate frames are based on a custom :class:`Timestep`
-object.
-
-.. autoclass:: Timestep
-   :members:
-
-   .. attribute:: _pos
-
-      coordinates of the atoms as a :class:`numpy.ndarray` of shape `(n_atoms, 3)`
-
-   .. attribute:: _velocities
-
-      velocities of the atoms as a :class:`numpy.ndarray` of shape `(n_atoms, 3)`;
-      only available if the trajectory contains velocities or if the
-      *velocities* = ``True`` keyword has been supplied.
-
-   .. attribute:: _forces
-
-      forces of the atoms as a :class:`numpy.ndarray` of shape `(n_atoms, 3)`;
-      only available if the trajectory contains forces or if the
-      *forces* = ``True`` keyword has been supplied.
-
 
 .. _netcdf-trajectories:
 
@@ -159,8 +137,10 @@ import logging
 from math import isclose
 
 import MDAnalysis
+from .timestep import Timestep
 from . import base
 from ..lib import util
+from ..lib.util import store_init_arguments
 logger = logging.getLogger("MDAnalysis.coordinates.AMBER")
 
 
@@ -171,19 +151,6 @@ except ImportError:
     logger.warning("netCDF4 is not available. Writing AMBER ncdf files will be slow.")
 
 
-class Timestep(base.Timestep):
-    """AMBER trajectory Timestep.
-
-    The Timestep can be initialized with `arg` being an integer
-    (the number of atoms) and an optional keyword argument `velocities` to
-    allocate space for both coordinates and velocities;
-
-    .. versionchanged:: 0.10.0
-       Added ability to contain Forces
-    """
-    order = 'C'
-
-
 class TRJReader(base.ReaderBase):
     """AMBER trajectory reader.
 
@@ -209,6 +176,7 @@ class TRJReader(base.ReaderBase):
     units = {'time': 'ps', 'length': 'Angstrom'}
     _Timestep = Timestep
 
+    @store_init_arguments
     def __init__(self, filename, n_atoms=None, **kwargs):
         super(TRJReader, self).__init__(filename, **kwargs)
         if n_atoms is None:
@@ -419,7 +387,7 @@ class NCDFReader(base.ReaderBase):
     to memory (using the :class:`~mmap.mmap`); ``mmap=False`` may consume large
     amounts of memory because it loads the whole trajectory into memory but it
     might be faster. The default is ``mmap=None`` and then default behavior of
-    :class:`scipy.io.netcdf.netcdf_file` prevails, i.e. ``True`` when
+    :class:`scipy.io.netcdf_file` prevails, i.e. ``True`` when
     *filename* is a file name, ``False`` when *filename* is a file-like object.
 
     .. _AMBER NETCDF format: http://ambermd.org/netcdf/nctraj.xhtml
@@ -448,7 +416,7 @@ class NCDFReader(base.ReaderBase):
        Support for reading `degrees` units for `cell_angles` has now been
        removed (Issue #2327)
     .. versionchanged:: 2.0.0
-       Now use a picklable :class:`scipy.io.netcdf.netcdf_file`--
+       Now use a picklable :class:`scipy.io.netcdf_file`--
        :class:`NCDFPicklable`.
        Reading of `dt` now defaults to 1.0 ps if `dt` cannot be extracted from
        the first two frames of the trajectory.
@@ -467,6 +435,7 @@ class NCDFReader(base.ReaderBase):
 
     _Timestep = Timestep
 
+    @store_init_arguments
     def __init__(self, filename, n_atoms=None, mmap=None, **kwargs):
 
         self._mmap = mmap
@@ -639,7 +608,7 @@ class NCDFReader(base.ReaderBase):
 
     @staticmethod
     def parse_n_atoms(filename, **kwargs):
-        with scipy.io.netcdf.netcdf_file(filename, mmap=None) as f:
+        with scipy.io.netcdf_file(filename, mmap=None) as f:
             n_atoms = f.dimensions['atom']
         return n_atoms
 
@@ -980,9 +949,9 @@ class NCDFWriter(base.WriterBase):
             ncfile = netCDF4.Dataset(self.filename, 'w',
                                      format='NETCDF3_64BIT')
         else:
-            ncfile = scipy.io.netcdf.netcdf_file(self.filename,
-                                                 mode='w', version=2,
-                                                 maskandscale=False)
+            ncfile = scipy.io.netcdf_file(self.filename,
+                                          mode='w', version=2,
+                                          maskandscale=False)
             wmsg = ("Could not find netCDF4 module. Falling back to MUCH "
                     "slower scipy.io.netcdf implementation for writing.")
             logger.warning(wmsg)
@@ -1206,11 +1175,11 @@ class NCDFWriter(base.WriterBase):
             self.trjfile = None
 
 
-class NCDFPicklable(scipy.io.netcdf.netcdf_file):
+class NCDFPicklable(scipy.io.netcdf_file):
     """NetCDF file object (read-only) that can be pickled.
 
     This class provides a file-like object (as returned by
-    :class:`scipy.io.netcdf.netcdf_file`) that,
+    :class:`scipy.io.netcdf_file`) that,
     unlike standard Python file objects,
     can be pickled. Only read mode is supported.
 
@@ -1222,7 +1191,7 @@ class NCDFPicklable(scipy.io.netcdf.netcdf_file):
 
 
     .. note::
-        This class subclasses :class:`scipy.io.netcdf.netcdf_file`, please
+        This class subclasses :class:`scipy.io.netcdf_file`, please
         see the `scipy netcdf API documentation`_ for more information on
         the parameters and how the class behaviour.
 
