@@ -49,7 +49,7 @@ import copy
 import numpy as np
 
 from ..lib import util
-from ..lib.util import asiterable
+from ..lib.util import asiterable, store_init_arguments
 from . import base
 from . import core
 
@@ -218,6 +218,7 @@ class ChainReader(base.ProtoReader):
     """
     format = 'CHAIN'
 
+    @store_init_arguments
     def __init__(self, filenames, skip=1, dt=None, continuous=False, **kwargs):
         """Set up the chain reader.
 
@@ -450,7 +451,7 @@ class ChainReader(base.ProtoReader):
         return self.active_reader.convert_pos_to_native(x)
 
     def copy(self):
-        new = self.__class__(copy.copy(self.filenames))
+        new = self.__class__(**self._kwargs)
         # seek the new reader to the same frame we started with
         new[self.ts.frame]
         # then copy over the current Timestep in case it has
@@ -555,7 +556,7 @@ class ChainReader(base.ProtoReader):
 
     def _read_frame(self, frame):
         """Position trajectory at frame index `frame` and
-        return :class:`~MDAnalysis.coordinates.base.Timestep`.
+        return :class:`~MDAnalysis.coordinates.timestep.Timestep`.
 
         The frame is translated to the corresponding reader and local
         frame index and the :class:`Timestep` instance in
