@@ -29,8 +29,8 @@ MDAnalysis. Using the *CHEMFILES* reader you can use  `chemfiles`_ for the low-l
 file reading. Check the list of `chemfile-supported file formats <formats>`_.
 
 .. _chemfiles: https://chemfiles.org
-.. _formats: https://chemfiles.org/chemfiles/0.9.3/formats.html#list-of-supported-formats
-.. NOTE: MDAnalysis currently restricts chemfiles to 0.9 <= version < 0.10. Update the link
+.. _formats: https://chemfiles.org/chemfiles/0.10.0/formats.html#list-of-supported-formats
+.. NOTE: MDAnalysis currently restricts chemfiles to 0.10 <= version < 0.11. Update the link
 ..       above to the latest documentation once this restriction is lifted.
 ..       https://chemfiles.org/chemfiles/latest/formats.html#list-of-supported-formats
 
@@ -79,12 +79,12 @@ Helper functions
 .. autofunction:: check_chemfiles_version
 
 """
-from distutils.version import LooseVersion
 import numpy as np
 import warnings
-import numpy as np
+from packaging.version import Version
 
 from . import base
+from ..lib.util import store_init_arguments
 
 try:
     import chemfiles
@@ -103,12 +103,10 @@ else:
     HAS_CHEMFILES = True
 
 
-#: Lowest version of chemfiles that is supported
-#: by MDAnalysis.
-MIN_CHEMFILES_VERSION = LooseVersion("0.9")
-#: Lowest version of chemfiles that is *not supported*
-#: by MDAnalysis.
-MAX_CHEMFILES_VERSION = LooseVersion("0.11")
+#: Lowest version of chemfiles that is supported by MDAnalysis.
+MIN_CHEMFILES_VERSION = Version("0.10")
+#: Lowest version of chemfiles that is *not supported* by MDAnalysis.
+MAX_CHEMFILES_VERSION = Version("0.11")
 
 
 def check_chemfiles_version():
@@ -122,19 +120,12 @@ def check_chemfiles_version():
     """
     if not HAS_CHEMFILES:
         warnings.warn(
-            "No Chemfiles package found.  "
-            "Try installing with 'pip install chemfiles'"
+            "chemfiles package not found, "
+            "try installing it with 'pip install chemfiles'"
         )
         return False
-    version = LooseVersion(chemfiles.__version__)
-    wrong = version < MIN_CHEMFILES_VERSION or version >= MAX_CHEMFILES_VERSION
-    if wrong:
-        warnings.warn(
-            "unsupported Chemfiles version {}, we need a version >{} and <{}".format(
-                version, MIN_CHEMFILES_VERSION, MAX_CHEMFILES_VERSION
-            )
-        )
-    return not wrong
+    version = Version(chemfiles.__version__)
+    return version >= MIN_CHEMFILES_VERSION and version < MAX_CHEMFILES_VERSION
 
 
 class ChemfilesReader(base.ReaderBase):
@@ -150,6 +141,7 @@ class ChemfilesReader(base.ReaderBase):
     format = "chemfiles"
     units = {"time": "fs", "length": "Angstrom"}
 
+    @store_init_arguments
     def __init__(self, filename, chemfiles_format="", **kwargs):
         """
         Parameters
@@ -401,11 +393,8 @@ class ChemfilesWriter(base.WriterBase):
         else:
             lengths = ts.dimensions[:3]
             angles = ts.dimensions[3:]
-            
-        if chemfiles.__version__.startswith("0.9"):
-            frame.cell = chemfiles.UnitCell(*lengths, *angles)
-        else:
-            frame.cell = chemfiles.UnitCell(lengths, angles)
+
+        frame.cell = chemfiles.UnitCell(lengths, angles)
 
         return frame
 
