@@ -1636,7 +1636,8 @@ def calc_dihedrals(coords1: Union[np.ndarray, 'AtomGroup'],
         Array containing the dihedral angles formed by each quadruplet of
         coordinates. Values are returned in radians (rad). If four single
         coordinates were supplied, the dihedral angle is returned as a single
-        number instead of an array.
+        number instead of an array. The range of dihedral angle is 
+        :math:`(-\pi, \pi)`.
 
 
     .. versionadded:: 0.8
