@@ -63,11 +63,13 @@ from ..exceptions import NoDataError
 from . import util
 from ._cutil import (make_whole, find_fragments, _sarrus_det_single,
                      _sarrus_det_multiple)
+import numpy.typing as npt
+from typing import Union
 
 # geometric functions
 
 
-def norm(v):
+def norm(v: npt.ArrayLike) -> float:
     r"""Calculate the norm of a vector v.
 
     .. math:: v = \sqrt{\mathbf{v}\cdot\mathbf{v}}
@@ -90,7 +92,8 @@ def norm(v):
     return np.sqrt(np.dot(v, v))
 
 
-def normal(vec1, vec2):
+# typing: numpy
+def normal(vec1: npt.ArrayLike, vec2: npt.ArrayLike) -> np.ndarray:
     r"""Returns the unit vector normal to two vectors.
 
     .. math::
@@ -110,7 +113,8 @@ def normal(vec1, vec2):
     return normal / n
 
 
-def pdot(a, b):
+# typing: numpy
+def pdot(a: npt.ArrayLike, b: npt.ArrayLike) -> np.ndarray:
     """Pairwise dot product.
 
     ``a`` must be the same shape as ``b``.
@@ -127,7 +131,8 @@ def pdot(a, b):
     return np.einsum('ij,ij->i', a, b)
 
 
-def pnorm(a):
+# typing: numpy
+def pnorm(a: npt.ArrayLike) -> np.ndarray:
     """Euclidean norm of each vector in a matrix
 
     Parameters
@@ -141,7 +146,7 @@ def pnorm(a):
     return pdot(a, a)**0.5
 
 
-def angle(a, b):
+def angle(a: npt.ArrayLike, b: npt.ArrayLike) -> float:
     """Returns the angle between two vectors in radians
 
     .. versionchanged:: 0.11.0
@@ -156,7 +161,7 @@ def angle(a, b):
     return np.arccos(x)
 
 
-def stp(vec1, vec2, vec3):
+def stp(vec1: npt.ArrayLike, vec2: npt.ArrayLike, vec3: npt.ArrayLike) -> float:
     r"""Takes the scalar triple product of three vectors.
 
     Returns the volume *V* of the parallel epiped spanned by the three
@@ -172,7 +177,7 @@ def stp(vec1, vec2, vec3):
     return np.dot(vec3, np.cross(vec1, vec2))
 
 
-def dihedral(ab, bc, cd):
+def dihedral(ab: npt.ArrayLike, bc: npt.ArrayLike, cd: npt.ArrayLike) -> float:
     r"""Returns the dihedral angle in radians between vectors connecting A,B,C,D.
 
     The dihedral measures the rotation around bc::
@@ -194,7 +199,8 @@ def dihedral(ab, bc, cd):
     return (x if stp(ab, bc, cd) <= 0.0 else -x)
 
 
-def sarrus_det(matrix):
+# typing: numpy
+def sarrus_det(matrix: np.ndarray) -> Union[float, np.ndarray]:
     """Computes the determinant of a 3x3 matrix according to the
     `rule of Sarrus`_.
 
@@ -239,7 +245,8 @@ def sarrus_det(matrix):
     return _sarrus_det_multiple(m.reshape((-1, 3, 3))).reshape(shape[:-2])
 
 
-def triclinic_box(x, y, z):
+# typing: numpy
+def triclinic_box(x: npt.ArrayLike, y: npt.ArrayLike, z: npt.ArrayLike) -> np.ndarray:
     """Convert the three triclinic box vectors to
     ``[lx, ly, lz, alpha, beta, gamma]``.
 
@@ -301,7 +308,8 @@ def triclinic_box(x, y, z):
     return np.zeros(6, dtype=np.float32)
 
 
-def triclinic_vectors(dimensions, dtype=np.float32):
+# typing: numpy
+def triclinic_vectors(dimensions: npt.ArrayLike, dtype: npt.DTypeLike = np.float32) -> np.ndarray:
     """Convert ``[lx, ly, lz, alpha, beta, gamma]`` to a triclinic matrix
     representation.
 
@@ -399,7 +407,7 @@ def triclinic_vectors(dimensions, dtype=np.float32):
     return box_matrix
 
 
-def box_volume(dimensions):
+def box_volume(dimensions: npt.ArrayLike) -> float:
     """Return the volume of the unitcell described by `dimensions`.
 
     The volume is computed as the product of the box matrix trace, with the
