@@ -176,7 +176,7 @@ def per_core_work(topology_file_path, trajectory_file_path, list_square_vertex_a
         list_centroids_this_frame = []
         for indices in list_indices_in_polygon:
             if not indices[0].size > 0:  # if there are no particles of interest in this particular square
-                list_centroids_this_frame.append('empty')
+                list_centroids_this_frame.append(None)
             else:
                 current_coordinate_array_in_square = relevant_particle_coordinate_array_xy[indices]
                 current_square_indices_centroid = np.average(current_coordinate_array_in_square, axis=0)
@@ -201,7 +201,7 @@ def per_core_work(topology_file_path, trajectory_file_path, list_square_vertex_a
             xy_deltas_to_write = []
             for square_1_centroid, square_2_centroid in zip(list_centroids_this_frame_using_indices_from_last_frame,
                                                             list_previous_frame_centroids):
-                if square_1_centroid == 'empty' or square_2_centroid == 'empty':
+                if square_1_centroid is None or square_2_centroid is None:
                     xy_deltas_to_write.append([0, 0])
                 else:
                     xy_deltas_to_write.append(np.subtract(square_1_centroid, square_2_centroid).tolist())
