@@ -31,11 +31,11 @@ from numpy.testing import (
 )
 import pytest
 from MDAnalysisTests.datafiles import PSF, DCD, PDB_CHECK_RIGHTHAND_PA, MMTF
-from MDAnalysisTests import make_Universe, no_deprecated_call
+from MDAnalysisTests import make_Universe
 
 import MDAnalysis as mda
 import MDAnalysis.core.topologyattrs as tpattrs
-from MDAnalysis.core import groups
+from MDAnalysis.core._get_readers import get_reader_for
 from MDAnalysis.core.topology import Topology
 from MDAnalysis.exceptions import NoDataError
 
@@ -176,7 +176,7 @@ class TestIndicesClasses(object):
 
 class TestAtomnames(TestAtomAttr):
     values = np.array(['O', 'C', 'CA', 'N', 'CB', 'CG', 'CD', 'NA', 'CL', 'OW'],
-                      dtype=np.object)
+                      dtype=object)
     single_value = 'Ca2'
     attrclass = tpattrs.Atomnames
 
@@ -185,12 +185,17 @@ class TestAtomnames(TestAtomAttr):
         return mda.Universe(PSF, DCD)
 
     def test_prev_emptyresidue(self, u):
-        assert_equal(u.residues[[]]._get_prev_residues_by_resid(),
-                     u.residues[[]])
+        # Checking group size rather than doing
+        # array comparison on zero-sized arrays (Issue #3535)
+        groupsize = len(u.residues[[]]._get_prev_residues_by_resid().atoms)
+        assert groupsize == 0
+        assert groupsize == len(u.residues[[]].atoms)
 
     def test_next_emptyresidue(self, u):
-        assert_equal(u.residues[[]]._get_next_residues_by_resid(),
-                     u.residues[[]])
+        # See above re: checking size for zero-sized arrays
+        groupsize = len(u.residues[[]]._get_next_residues_by_resid().atoms)
+        assert groupsize == 0
+        assert groupsize == len(u.residues[[]].atoms)
 
 
 class AggregationMixin(TestAtomAttr):
@@ -517,6 +522,7 @@ def test_static_typing_from_empty():
 
 @pytest.mark.parametrize('level, transplant_name', (
     ('atoms', 'center_of_mass'),
+    ('atoms', 'center_of_charge'),
     ('atoms', 'total_charge'),
     ('residues', 'total_charge'),
 ))
@@ -585,3 +591,103 @@ class TestDeprecateBFactor:
     def test_deprecate_bfactor_sel(self, universe):
         with pytest.warns(DeprecationWarning, match=self.MATCH):
             universe.select_atoms("bfactor 3")
+
+
+class TestStringInterning:
+    # try and trip up the string interning we use for string attributes
+    @pytest.fixture
+    def universe(self):
+        u = mda.Universe.empty(n_atoms=10, n_residues=2,
+                               atom_resindex=[0]*5 + [1] * 5)
+        u.add_TopologyAttr('names', values=['A'] * 10)
+        u.add_TopologyAttr('resnames', values=['ResA', 'ResB'])
+        u.add_TopologyAttr('segids', values=['SegA'])
+
+        return u
+
+    @pytest.mark.parametrize('newname', ['ResA', 'ResB'])
+    def test_add_residue(self, universe, newname):
+        newres = universe.add_Residue(resname=newname)
+
+        assert newres.resname == newname
+
+        ag = universe.atoms[2]
+        ag.residue = newres
+
+        assert ag.resname == newname
+
+    @pytest.mark.parametrize('newname', ['SegA', 'SegB'])
+    def test_add_segment(self, universe, newname):
+        newseg = universe.add_Segment(segid=newname)
+
+        assert newseg.segid == newname
+
+        rg = universe.residues[0]
+        rg.segment = newseg
+
+        assert rg.atoms[0].segid == newname
+
+    def test_issue3437(self, universe):
+        newseg = universe.add_Segment(segid='B')
+
+        ag = universe.residues[0].atoms
+
+        ag.residues.segments = newseg
+
+        assert 'B' in universe.segments.segids
+
+        ag2 = universe.select_atoms('segid B')
+
+        assert len(ag2) == 5
+        assert (ag2.ix == ag.ix).all()
+
+
+class Testcenter_of_charge():
+
+    compounds = ['group', 'segments', 'residues', 'molecules', 'fragments']
+
+    @pytest.fixture
+    def u(self):
+        """A universe containing two dimers with a finite dipole moment."""
+        universe = mda.Universe.empty(n_atoms=4,
+                                      n_residues=2,
+                                      n_segments=2,
+                                      atom_resindex=[0, 0, 1, 1],
+                                      residue_segindex=[0, 1])
+
+        universe.add_TopologyAttr("masses", [1, 0, 0, 1])
+        universe.add_TopologyAttr("charges", [1, -1, -1, 1])
+        universe.add_TopologyAttr("bonds", ((0, 1), (2, 3)))
+        universe.add_TopologyAttr("resids", [0, 1])
+        universe.add_TopologyAttr("molnums", [0, 1])
+
+        positions = np.array([[0, 0, 0], [0, 1, 0], [2, 1, 0], [2, 2, 0]])
+
+        universe.trajectory = get_reader_for(positions)(positions,
+                                                        order='fac',
+                                                        n_atoms=4)
+
+        for ts in universe.trajectory:
+            ts.dimensions = np.array([1, 2, 3, 90, 90, 90])
+
+        return universe
+
+    @pytest.mark.parametrize('compound', compounds)
+    def test_coc(self, u, compound):
+        coc = u.atoms.center_of_charge(compound=compound)
+        if compound == "group":
+            coc_ref = [1, 1, 0]
+        else:
+            coc_ref = [[0, 0.5, 0], [2, 1.5, 0]]
+        assert_equal(coc, coc_ref)
+
+    @pytest.mark.parametrize('compound', compounds)
+    def test_coc_wrap(self, u, compound):
+        coc = u.atoms[:2].center_of_charge(compound=compound, wrap=True)
+        assert_equal(coc.flatten(), [0, 0.5, 0])
+
+    @pytest.mark.parametrize('compound', compounds)
+    def test_coc_unwrap(self, u, compound):
+        u.atoms.wrap
+        coc = u.atoms[:2].center_of_charge(compound=compound, unwrap=True)
+        assert_equal(coc.flatten(), [0, -0.5, 0])
