@@ -127,6 +127,10 @@ __all__ = [
     "TRIC",
     "XTC_multi_frame",
     "TRR_multi_frame",
+    "TNG_traj",  # TNG trajectory from GROMACS physical validation testsuite, longish trajectory
+    "TNG_traj_gro",  # topology for argon_npt_compressed_traj
+    "TNG_traj_uneven_blocks",  # TNG trajectory with pos and vel deposited on different strides
+    "TNG_traj_vels_forces",  # similar to above but with velocities and forces
     "merge_protein", "merge_ligand", "merge_water",
     "mol2_molecules", "mol2_molecule", "mol2_broken_molecule",
     "mol2_zinc", "mol2_comments_header", "mol2_ligand", "mol2_sodium_ion",
@@ -143,6 +147,8 @@ __all__ = [
     "LAMMPSDUMP_allcoords",  # lammpsdump file with all coordinate conventions (x,xs,xu,xsu) present, from LAMMPS rdf example
     "LAMMPSDUMP_nocoords",  # lammpsdump file with no coordinates
     "LAMMPSDUMP_triclinic", # lammpsdump file to test triclinic dimension parsing, albite with most atoms deleted
+    "LAMMPSDUMP_image_vf", # Lammps dump file with image flags, velocities, and forces.
+    "LAMMPS_image_vf", # Lammps data file to go with LAMMPSDUMP_image_vf
     "unordered_res",  # pdb file with resids non sequential
     "GMS_ASYMOPT",  # GAMESS C1  optimization
     "GMS_SYMOPT",   # GAMESS D4h optimization
@@ -166,6 +172,7 @@ __all__ = [
     "Martini_membrane_gro", # for testing the leaflet finder
     "COORDINATES_XTC",
     "COORDINATES_TRR",
+    "COORDINATES_TNG",
     "COORDINATES_H5MD",
     "COORDINATES_DCD",
     "COORDINATES_TOPOLOGY",
@@ -176,6 +183,8 @@ __all__ = [
     "RANDOM_WALK_TOPO", # garbage topology to go along with XTC positions above
     "AUX_XVG", "XVG_BAD_NCOL", #for testing .xvg auxiliary reader
     "AUX_XVG_LOWF", "AUX_XVG_HIGHF",
+    "AUX_EDR", "AUX_EDR_TPR",
+    "AUX_EDR_XTC", "AUX_EDR_RAW",  # for testing .edr auxiliary reader
     "MMTF", "MMTF_gz", 'MMTF_skinny',  # skinny - some optional fields stripped out
     "MMTF_skinny2",
     "ALIGN_BOUND",  # two component bound system
@@ -240,6 +249,10 @@ AUX_XVG_LOWF = resource_filename(__name__, 'data/test_lowf.xvg')
 AUX_XVG_HIGHF = resource_filename(__name__, 'data/test_highf.xvg')
 XVG_BAD_NCOL = resource_filename(__name__, 'data/bad_num_col.xvg')
 AUX_XVG = resource_filename(__name__, 'data/test.xvg')
+AUX_EDR = resource_filename(__name__, 'data/test.edr')
+AUX_EDR_RAW = resource_filename(__name__, 'data/aux_edr_raw.txt')
+AUX_EDR_TPR = resource_filename(__name__, 'data/aux_edr.tpr')
+AUX_EDR_XTC = resource_filename(__name__, 'data/aux_edr.xtc')
 ENT = resource_filename(__name__, 'data/testENT.ent')
 GRO_missing_atomname = resource_filename(__name__, 'data/missing_atomname.gro')
 GRO_empty_atom = resource_filename(__name__, 'data/empty_atom.gro')
@@ -253,6 +266,7 @@ COORDINATES_XYZ_BZ2 = resource_filename(
     __name__, 'data/coordinates/test.xyz.bz2')
 COORDINATES_XTC = resource_filename(__name__, 'data/coordinates/test.xtc')
 COORDINATES_TRR = resource_filename(__name__, 'data/coordinates/test.trr')
+COORDINATES_TNG = resource_filename(__name__, 'data/coordinates/test.tng')
 COORDINATES_H5MD = resource_filename(__name__, 'data/coordinates/test.h5md')
 COORDINATES_DCD = resource_filename(__name__, 'data/coordinates/test.dcd')
 COORDINATES_TOPOLOGY = resource_filename(__name__, 'data/coordinates/test_topology.pdb')
@@ -328,7 +342,10 @@ XTC_multi_frame = resource_filename(
 TRR_multi_frame = resource_filename(
     __name__, 'data/trr_test_only_10_frame_10_atoms.trr'
 )
-
+TNG_traj = resource_filename(__name__, 'data/argon_npt_compressed.tng')
+TNG_traj_gro = resource_filename(__name__, 'data/argon_npt_compressed.gro.gz')
+TNG_traj_uneven_blocks = resource_filename(__name__, 'data/argon_npt_compressed_uneven.tng')
+TNG_traj_vels_forces = resource_filename(__name__, 'data/argon_npt_compressed_vels_forces.tng')
 PDB_xvf = resource_filename(__name__, 'data/cobrotoxin.pdb')
 TPR_xvf = resource_filename(__name__, 'data/cobrotoxin.tpr')
 TRR_xvf = resource_filename(__name__, 'data/cobrotoxin.trr')
@@ -501,7 +518,8 @@ LAMMPSDUMP_long = resource_filename(__name__, "data/lammps/wat.lammpstrj_long.bz
 LAMMPSDUMP_allcoords = resource_filename(__name__, "data/lammps/spce_all_coords.lammpstrj.bz2")
 LAMMPSDUMP_nocoords = resource_filename(__name__, "data/lammps/spce_no_coords.lammpstrj.bz2")
 LAMMPSDUMP_triclinic = resource_filename(__name__, "data/lammps/albite_triclinic.dump")
-
+LAMMPSDUMP_image_vf = resource_filename(__name__, "data/lammps/image_vf.lammpstrj")
+LAMMPS_image_vf = resource_filename(__name__, "data/lammps/image_vf.data")
 
 unordered_res = resource_filename(__name__, "data/unordered_res.pdb")
 
