@@ -40,7 +40,8 @@ import MDAnalysis as mda
 import MDAnalysis.lib.util as util
 import MDAnalysis.lib.mdamath as mdamath
 from MDAnalysis.lib.util import (cached, static_variables, warn_if_not_unique,
-                                 check_coords, store_init_arguments,)
+                                 check_coords, store_init_arguments, 
+                                 check_atomgroup_not_empty,)
 from MDAnalysis.core.topologyattrs import Bonds
 from MDAnalysis.exceptions import NoDataError, DuplicateWarning
 from MDAnalysis.core.groups import AtomGroup
@@ -1534,7 +1535,7 @@ class TestStaticVariables(object):
 
 
 class TestWarnIfNotUnique(object):
-    """Tests concerning the decorator @warn_if_not_uniue
+    """Tests concerning the decorator @warn_if_not_unique
     """
 
     def warn_msg(self, func, group, group_name):
@@ -1568,10 +1569,11 @@ class TestWarnIfNotUnique(object):
 
         # Check that no warning is raised for a unique group:
         assert atoms.isunique
-        with pytest.warns(None) as w:
+
+        with warnings.catch_warnings():
+            warnings.simplefilter("error")
             x = outer(atoms)
             assert x == 0
-            assert not w.list
 
         # Check that a warning is raised for a group with duplicates:
         ag = atoms + atoms[0]
@@ -1699,9 +1701,9 @@ class TestWarnIfNotUnique(object):
         with warnings.catch_warnings(record=True) as record:
             warnings.resetwarnings()
             warnings.filterwarnings("ignore", category=UserWarning)
-            with pytest.warns(None) as w:
+            with warnings.catch_warnings():
+                warnings.simplefilter("error")
                 func(atoms)
-                assert not w.list
             assert len(record) == 0
 
 
